@@ -21,7 +21,7 @@ def test_framework_drop_rows_with_null_transformer(spark_session: SparkSession)
     view: str = "primary_care_protocol"
     FrameworkCsvLoader(
         view=view,
-        path_to_csv=data_dir.joinpath("primary_care_protocol.csv"),
+        filepath=data_dir.joinpath("primary_care_protocol.csv"),
         clean_column_names=False,
     ).transform(df)
 
